@@ -3,11 +3,11 @@
 package ddsnmp
 
 import (
-	"errors"
 	"io/fs"
 	"os"
 	"path/filepath"
 	"strings"
+	"sync"
 
 	"gopkg.in/yaml.v2"
 
@@ -17,32 +17,32 @@ import (
 
 var log = logger.New().With("component", "snmp/ddsnmp")
 
-var ddProfiles []*Profile
+var (
+	ddProfiles []*Profile
+	loadOnce   sync.Once
+)
 
-func init() {
-	dir := os.Getenv("NETDATA_STOCK_CONFIG_DIR")
-	if dir != "" {
-		dir = filepath.Join(dir, "go.d/snmp.profiles/default")
-	} else {
-		if dir, _ = filepath.Abs("../../../config/go.d/snmp.profiles/default"); !isDirExists(dir) {
-			dir = filepath.Join(executable.Directory, "../../../../usr/lib/netdata/conf.d/go.d/snmp.profiles/default")
+func load() {
+	loadOnce.Do(func() {
+		dir := getProfilesDir()
+
+		profiles, err := loadProfiles(dir)
+		if err != nil {
+			log.Errorf("failed to loadProfiles dd snmp profiles: %v", err)
+			return
 		}
-	}
-	profiles, err := load(dir)
-	if err != nil {
-		log.Errorf("failed to load dd snmp profiles: %v", err)
-		return
-	}
-	if len(profiles) == 0 {
-		log.Warningf("no dd snmp profiles found in '%s'", dir)
-		return
-	}
 
-	log.Infof("found %d profiles in '%s'", len(profiles), dir)
-	ddProfiles = profiles
+		if len(profiles) == 0 {
+			log.Warningf("no dd snmp profiles found in '%s'", dir)
+			return
+		}
+
+		log.Infof("found %d profiles in '%s'", len(profiles), dir)
+		ddProfiles = profiles
+	})
 }
 
-func load(dirpath string) ([]*Profile, error) {
+func loadProfiles(dirpath string) ([]*Profile, error) {
 	var profiles []*Profile
 
 	if err := filepath.WalkDir(dirpath, func(path string, d fs.DirEntry, err error) error {
@@ -90,22 +90,43 @@ func loadProfile(filename string) (*Profile, error) {
 
 	dir := filepath.Dir(filename)
 
-	for _, name := range prof.Definition.Extends {
-		baseProf, err := loadProfile(filepath.Join(dir, name))
-		if err != nil {
-			return nil, err
-		}
-
-		prof.merge(baseProf)
+	processedExtends := make(map[string]bool)
+	if err := loadProfileExtensions(&prof, dir, processedExtends); err != nil {
+		return nil, err
 	}
 
 	return &prof, nil
 }
 
-func isDirExists(dir string) bool {
-	fi, err := os.Stat(dir)
-	if err != nil {
-		return !errors.Is(err, fs.ErrNotExist)
+func loadProfileExtensions(profile *Profile, dir string, processedExtends map[string]bool) error {
+	for _, name := range profile.Definition.Extends {
+		if processedExtends[name] {
+			continue
+		}
+		processedExtends[name] = true
+
+		baseProf, err := loadProfile(filepath.Join(dir, name))
+		if err != nil {
+			return err
+		}
+
+		if err := loadProfileExtensions(baseProf, dir, processedExtends); err != nil {
+			return err
+		}
+
+		profile.merge(baseProf)
 	}
-	return fi.Mode().IsDir()
+
+	return nil
+}
+
+func getProfilesDir() string {
+	if executable.Name == "test" {
+		dir, _ := filepath.Abs("../../../config/go.d/snmp.profiles/default")
+		return dir
+	}
+	if dir := os.Getenv("NETDATA_STOCK_CONFIG_DIR"); dir != "" {
+		return filepath.Join(dir, "go.d/snmp.profiles/default")
+	}
+	return filepath.Join(executable.Directory, "../../../config/go.d/snmp.profiles/default")
 }
